==> viha-5.15.tar.gz: viha-5.15/kalusto-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "laite";
$file = "kalusto-takt.php";

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmien varustaminen</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", ryhmien varustaminen</h1>
";

taktiset_linkit();

print "<form action=\"\" method=\"GET\">\n";

# laitteet

$sql_tail = "
FROM laite, ryhma, laite_tyyppi, verkko, jarjesto
WHERE ryhma.id = laite.ryhma_id AND laite_tyyppi.id = laite.laite_tyyppi_id
      AND verkko.id = laite.verkko_id
      AND jarjesto.id = laite.jarjesto_id
      AND laite.paivystys_id = " . s("paivystys") . "
ORDER BY jarjesto.jarjesto, laite.laite, laite.tunniste
";
$columns = 2;
$items = ota_yksi("
SELECT COUNT(*)
$sql_tail
");
$percol = intval(floor(($items + $columns - 1) / $columns));
print "<p><b>Viestivlineet, yhteens $items</b>\n";
$sql = "
SELECT laite.id, laite.jarjesto_id, laite.laite, laite.tunniste,
       ryhma.kutsu, laite_tyyppi, verkko, jarjesto.jarjesto
$sql_tail
";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
	. tr_bgcolor()
	. "<TH>Jrjest<TH>Viestivline<TH>Verkko<TH>Tyyppi<TH>Ryhm\n";
    }
    echo "<tr><td>" . jarjesto_personal($a[jarjesto_id]),
      "<TD>"
      . "<a href=\"laite-takt-1.php?id=$a[id]\">$a[laite] ($a[tunniste])</a>",
      "<td>$a[verkko]",
      "<td>$a[laite_tyyppi]",
      "<td>$a[kutsu]",
      "\n";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "
  </table>\n";
    }
    $n ++;
  }
  echo "</TABLE>";
} else {
    echo "<P>Plop. Ei viestivlineit.";
}

# tavarat

$sql_tail = "
FROM tavara, ryhma, tavara_tyyppi, jarjesto
WHERE ryhma.id = tavara.ryhma_id AND tavara_tyyppi.id = tavara.tavara_tyyppi_id
      AND jarjesto.id = tavara.jarjesto_id
      AND tavara.paivystys_id = " . s("paivystys") . "
ORDER BY jarjesto.jarjesto, tavara.tavara, tavara.tunniste
";
$columns = 2;
$items = ota_yksi("
SELECT COUNT(*)
$sql_tail
");
$percol = intval(floor(($items + $columns - 1) / $columns));
print "<p><b>Muu kalusto, yhteens $items</b>\n";
$sql = "
SELECT tavara.id, tavara.jarjesto_id, tavara.tavara, tavara.tunniste,
       ryhma.kutsu, tavara_tyyppi, jarjesto.jarjesto
$sql_tail
";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
	. tr_bgcolor()
	. "<TH>Jrjest<TH>Tavara<TH>Tyyppi<TH>Ryhm\n";
    }
    echo "<tr><td>" . jarjesto_personal($a[jarjesto_id]),
      "<TD>"
      . "<a href=\"tavara-takt-1.php?id=$a[id]\">"
      . "$a[tavara] ($a[tunniste])</a>",
      "<td>$a[tavara_tyyppi]",
      "<td>$a[kutsu]",
      "\n";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "
  </table>\n";
    }
    $n ++;
  }
  echo "</TABLE>";
} else {
    echo "<P>Plop. Ei tavaroita.";
}

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: kalusto-takt.php,v 1.15 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/kalusto-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "laite";
$file = "kalusto-takt.php";

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmien varustaminen</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", ryhmien varustaminen</h1>
";

taktiset_linkit();

print "<form action=\"\" method=\"GET\">\n";

# laitteet

$sql_tail = "
FROM laite, ryhma, laite_tyyppi, verkko, jarjesto
WHERE ryhma.id = laite.ryhma_id AND laite_tyyppi.id = laite.laite_tyyppi_id
      AND verkko.id = laite.verkko_id
      AND jarjesto.id = laite.jarjesto_id
      AND laite.paivystys_id = " . s("paivystys") . "
ORDER BY jarjesto.jarjesto, laite.laite, laite.tunniste
";
$columns = 2;
$items = ota_yksi("
SELECT COUNT(*)
$sql_tail
");
$percol = intval(floor(($items + $columns - 1) / $columns));
print "<p><b>Viestivlineet, yhteens $items</b>\n";
$sql = "
SELECT laite.id, laite.jarjesto_id, laite.laite, laite.tunniste,
       ryhma.kutsu, laite_tyyppi, verkko, jarjesto.jarjesto
$sql_tail
";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
	. tr_vaalsin()
	. "<TH>Jrjest<TH>Viestivline<TH>Verkko<TH>Tyyppi<TH>Ryhm\n";
    }
    echo "<tr><td>" . jarjesto_personal($a[jarjesto_id]),
      "<TD>"
      . "<a href=\"laite-takt-1.php?id=$a[id]\">$a[laite] ($a[tunniste])</a>",
      "<td>$a[verkko]",
      "<td>$a[laite_tyyppi]",
      "<td>$a[kutsu]",
      "\n";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "
  </table>\n";
    }
    $n ++;
  }
  echo "</TABLE>";
} else {
    echo "<P>Plop. Ei viestivlineit.";
}

# tavarat

$sql_tail = "
FROM tavara, ryhma, tavara_tyyppi, jarjesto
WHERE ryhma.id = tavara.ryhma_id AND tavara_tyyppi.id = tavara.tavara_tyyppi_id
      AND jarjesto.id = tavara.jarjesto_id
      AND tavara.paivystys_id = " . s("paivystys") . "
ORDER BY jarjesto.jarjesto, tavara.tavara, tavara.tunniste
";
$columns = 2;
$items = ota_yksi("
SELECT COUNT(*)
$sql_tail
");
$percol = intval(floor(($items + $columns - 1) / $columns));
print "<p><b>Muu kalusto, yhteens $items</b>\n";
$sql = "
SELECT tavara.id, tavara.jarjesto_id, tavara.tavara, tavara.tunniste,
       ryhma.kutsu, tavara_tyyppi, jarjesto.jarjesto
$sql_tail
";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
	. tr_vaalsin()
	. "<TH>Jrjest<TH>Tavara<TH>Tyyppi<TH>Ryhm\n";
    }
    echo "<tr><td>" . jarjesto_personal($a[jarjesto_id]),
      "<TD>"
      . "<a href=\"tavara-takt-1.php?id=$a[id]\">"
      . "$a[tavara] ($a[tunniste])</a>",
      "<td>$a[tavara_tyyppi]",
      "<td>$a[kutsu]",
      "\n";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "
  </table>\n";
    }
    $n ++;
  }
  echo "</TABLE>";
} else {
    echo "<P>Plop. Ei tavaroita.";
}

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: kalusto-takt.php,v 1.17 2009/09/29 16:09:15 riku Exp $ -->
